@@ -3,7 +3,7 @@ Overview:
     Reflection module, include some useful utilities for the python language.
 """
 from .clazz import *
-from .enum import *
 from .exception import *
 from .func import *
 from .imports import *
+from .iter import *
